@@ -267,7 +267,8 @@ let readbyte_of_fd fd =
   readbyte_of_readfun 
     (fun buf off len ->
        try Unix.read fd buf off len
-       with exn -> Unix.close fd;raise exn)
+       with exn -> 
+	 (try Unix.close fd with _ -> ());raise exn)
 
 (* a readbyte implementation which reads from an SSL socket. It is
    otherwise the same as rb_of_fd *)
@@ -275,7 +276,8 @@ let readbyte_of_ssl fd =
   readbyte_of_readfun
     (fun buf off len -> 
        try Ssl.read fd buf off len
-       with exn -> Ssl.shutdown fd;raise exn)
+       with exn ->
+	 (try Ssl.shutdown fd with _ -> ());raise exn)
 
 let decode_ber_length ?(peek=false) (readbyte:readbyte) = (* sec. 8.1.3.3, the definite length form *)
   let octet = int_of_char (readbyte ~peek:peek 1).[0] in
